about summary refs log tree commit diff
path: root/src/liballoc
diff options
context:
space:
mode:
authorSimon Sapin <simon.sapin@exyr.org>2017-12-27 22:56:06 +0100
committerSimon Sapin <simon.sapin@exyr.org>2018-01-20 11:09:23 +0100
commit12b3630f62e2412fa2f7d50b765cd6d711b74064 (patch)
tree90cc1f5833122368b840ea4b0b7a52bfb4c290e5 /src/liballoc
parent8ef5e549c3cec025c6b7c37931bddd68f2fcab4a (diff)
downloadrust-12b3630f62e2412fa2f7d50b765cd6d711b74064.tar.gz
rust-12b3630f62e2412fa2f7d50b765cd6d711b74064.zip
Rename Box::into_non_null_raw to Box::into_raw_non_null
Diffstat (limited to 'src/liballoc')
-rw-r--r--src/liballoc/arc.rs4
-rw-r--r--src/liballoc/boxed.rs12
-rw-r--r--src/liballoc/linked_list.rs6
-rw-r--r--src/liballoc/rc.rs4
4 files changed, 13 insertions, 13 deletions
diff --git a/src/liballoc/arc.rs b/src/liballoc/arc.rs
index 95ba517a7a9..6a77bf64bae 100644
--- a/src/liballoc/arc.rs
+++ b/src/liballoc/arc.rs
@@ -286,7 +286,7 @@ impl<T> Arc<T> {
             weak: atomic::AtomicUsize::new(1),
             data,
         };
-        Arc { ptr: Box::into_non_null_raw(x), phantom: PhantomData }
+        Arc { ptr: Box::into_raw_non_null(x), phantom: PhantomData }
     }
 
     /// Returns the contained value, if the `Arc` has exactly one strong reference.
@@ -991,7 +991,7 @@ impl<T> Weak<T> {
     pub fn new() -> Weak<T> {
         unsafe {
             Weak {
-                ptr: Box::into_non_null_raw(box ArcInner {
+                ptr: Box::into_raw_non_null(box ArcInner {
                     strong: atomic::AtomicUsize::new(0),
                     weak: atomic::AtomicUsize::new(1),
                     data: uninitialized(),
diff --git a/src/liballoc/linked_list.rs b/src/liballoc/linked_list.rs
index 8ec0110060a..3cc810a055f 100644
--- a/src/liballoc/linked_list.rs
+++ b/src/liballoc/linked_list.rs
@@ -157,7 +157,7 @@ impl<T> LinkedList<T> {
         unsafe {
             node.next = self.head;
             node.prev = None;
-            let node = Some(Box::into_non_null_raw(node));
+            let node = Some(Box::into_raw_non_null(node));
 
             match self.head {
                 None => self.tail = node,
@@ -192,7 +192,7 @@ impl<T> LinkedList<T> {
         unsafe {
             node.next = None;
             node.prev = self.tail;
-            let node = Some(Box::into_non_null_raw(node));
+            let node = Some(Box::into_raw_non_null(node));
 
             match self.tail {
                 None => self.head = node,
@@ -986,7 +986,7 @@ impl<'a, T> IterMut<'a, T> {
                     Some(prev) => prev,
                 };
 
-                let node = Some(Box::into_non_null_raw(box Node {
+                let node = Some(Box::into_raw_non_null(box Node {
                     next: Some(head),
                     prev: Some(prev),
                     element,
diff --git a/src/liballoc/rc.rs b/src/liballoc/rc.rs
index c3270e4e21d..1fa5d34cb57 100644
--- a/src/liballoc/rc.rs
+++ b/src/liballoc/rc.rs
@@ -311,7 +311,7 @@ impl<T> Rc<T> {
             // pointers, which ensures that the weak destructor never frees
             // the allocation while the strong destructor is running, even
             // if the weak pointer is stored inside the strong one.
-            ptr: Box::into_non_null_raw(box RcBox {
+            ptr: Box::into_raw_non_null(box RcBox {
                 strong: Cell::new(1),
                 weak: Cell::new(1),
                 value,
@@ -1190,7 +1190,7 @@ impl<T> Weak<T> {
     pub fn new() -> Weak<T> {
         unsafe {
             Weak {
-                ptr: Box::into_non_null_raw(box RcBox {
+                ptr: Box::into_raw_non_null(box RcBox {
                     strong: Cell::new(0),
                     weak: Cell::new(1),
                     value: uninitialized(),
diff --git a/src/liballoc/boxed.rs b/src/liballoc/boxed.rs
index 60998bc677b..78a4b337711 100644
--- a/src/liballoc/boxed.rs
+++ b/src/liballoc/boxed.rs
@@ -295,7 +295,7 @@ impl<T: ?Sized> Box<T> {
     #[stable(feature = "box_raw", since = "1.4.0")]
     #[inline]
     pub fn into_raw(b: Box<T>) -> *mut T {
-        Box::into_non_null_raw(b).as_ptr()
+        Box::into_raw_non_null(b).as_ptr()
     }
 
     /// Consumes the `Box`, returning the wrapped pointer as `NonNull<T>`.
@@ -308,8 +308,8 @@ impl<T: ?Sized> Box<T> {
     /// function.
     ///
     /// Note: this is an associated function, which means that you have
     /// to call it as `Box::into_non_null_raw(b)`
     /// instead of `b.into_non_null_raw()`. This
     /// is so that there is no conflict with a method on the inner type.
     ///
     /// [`Box::from_raw`]: struct.Box.html#method.from_raw
@@ -319,16 +319,16 @@ impl<T: ?Sized> Box<T> {
     /// ```
     /// fn main() {
     ///     let x = Box::new(5);
-    ///     let ptr = Box::into_non_null_raw(x);
+    ///     let ptr = Box::into_raw_non_null(x);
     /// }
     /// ```
     #[stable(feature = "nonnull", since = "1.24.0")]
     #[inline]
-    pub fn into_non_null_raw(b: Box<T>) -> NonNull<T> {
+    pub fn into_raw_non_null(b: Box<T>) -> NonNull<T> {
         Box::into_unique(b).into()
     }
 
-    #[unstable(feature = "ptr_internals", issue = "0", reason = "use into_non_null_raw instead")]
+    #[unstable(feature = "ptr_internals", issue = "0", reason = "use into_raw_non_null instead")]
     #[inline]
     pub fn into_unique(b: Box<T>) -> Unique<T> {
         let unique = b.0;
@@ -308,8 +308,8 @@ impl<T: ?Sized> Box<T> {
     ///
     /// Note: this is an associated function, which means that you have
-    /// to call it as `Box::into_non_null_raw(b)`
-    /// instead of `b.into_non_null_raw()`. This
+    /// to call it as `Box::into_raw_non_null(b)`
+    /// instead of `b.into_raw_non_null()`. This
     /// is so that there is no conflict with a method on the inner type.
     ///